@@ -1,12 +1,17 @@
 default_screenshot_args <- function(screenshot_args) {
-  if (is_missing_value(screenshot_args) || is.null(screenshot_args) || isTRUE(screenshot_args)) {
+  if (
+    is_missing_value(screenshot_args) ||
+      is.null(screenshot_args) ||
+      isTRUE(screenshot_args)
+  ) {
     screenshot_args <- list()
   }
   screenshot_args
 }
 
 app_get_screenshot <- function(
-  self, private,
+  self,
+  private,
   file = NULL,
   ...,
   screenshot_args = missing_arg(),
@@ -21,15 +26,32 @@ app_get_screenshot <- function(
     maybe_missing_value(screenshot_args, private$default_screenshot_args)
   )
   if (is_false(screenshot_args)) {
-    app_warn(self, private, "`screenshot_args` can not be `FALSE` when calling `app$get_screenshot()`. Setting to `list()`")
+    app_warn(
+      self,
+      private,
+      "`screenshot_args` can not be `FALSE` when calling `app$get_screenshot()`. Setting to `list()`"
+    )
     screenshot_args <- list()
   }
   checkmate::assert_list(screenshot_args)
 
-  screenshot_args$delay <- maybe_missing_value(delay, screenshot_args$delay) %||% 0
-  checkmate::assert_number(screenshot_args$delay, lower = 0, finite = TRUE, null.ok = TRUE)
+  screenshot_args$delay <- maybe_missing_value(
+    delay,
+    screenshot_args$delay
+  ) %||%
+    0
+  checkmate::assert_number(
+    screenshot_args$delay,
+    lower = 0,
+    finite = TRUE,
+    null.ok = TRUE
+  )
 
-  screenshot_args$selector <- maybe_missing_value(selector, screenshot_args$selector) %||% "scrollable_area"
+  screenshot_args$selector <- maybe_missing_value(
+    selector,
+    screenshot_args$selector
+  ) %||%
+    "scrollable_area"
   screenshot_args <- handle_custom_selector(self, private, screenshot_args)
 
   if (is.null(file)) {
@@ -62,17 +84,17 @@ app_get_screenshot <- function(
 
 
 app_expect_screenshot <- function(
-  self, private,
+  self,
+  private,
   ...,
-  threshold = NULL,
-  kernel_size = 5,
+  threshold = getOption("shinytest2.compare_screenshot.threshold", NULL),
+  kernel_size = getOption("shinytest2.compare_screenshot.kernel_size", 5),
   quiet = FALSE,
   name = NULL,
   screenshot_args = missing_arg(),
   delay = missing_arg(),
   selector = missing_arg(),
-  compare = missing_arg(),
-  cran = FALSE
+  compare = missing_arg()
 ) {
   "!DEBUG app_expect_screenshot()"
   ckm8_assert_app_driver(self, private)
@@ -82,7 +104,8 @@ app_expect_screenshot <- function(
     compare,
     function(old, new) {
       compare_screenshot_threshold(
-        old, new,
+        old,
+        new,
         threshold = threshold,
         kernel_size = kernel_size,
         quiet = quiet
@@ -102,27 +125,33 @@ app_expect_screenshot <- function(
 
   # Assert screenshot value
   app__expect_snapshot_file(
-    self, private,
+    self,
+    private,
     filename,
-    cran = cran,
     compare = compare
   )
 }
 
-app_expect_screenshot_and_variant <- function( # nolint
-  self, private,
-  ...
-) {
-  if (app_is_missing_variant(self, private)) {
-    app_abort(self, private, c(
-      "This `AppDriver` object can not call `$expect_screenshot()` without a `variant` initialized. Please supply a `variant` value when creating your `AppDriver` object, like `AppDriver(variant = <value>)`",
-      i = "`variant = platform_variant()` is the suggested value",
-      i = "`variant = NULL` can work, but screenshots are known to cause conflicts when changing R version or platform."
-    ))
+app_expect_screenshot_and_variant <- # nolint
+  function(
+    self,
+    private,
+    ...
+  ) {
+    if (app_is_missing_variant(self, private)) {
+      app_abort(
+        self,
+        private,
+        c(
+          "This `AppDriver` object can not call `$expect_screenshot()` without a `variant` initialized. Please supply a `variant` value when creating your `AppDriver` object, like `AppDriver(variant = <value>)`",
+          i = "`variant = platform_variant()` is the suggested value",
+          i = "`variant = NULL` can work, but screenshots are known to cause conflicts when changing R version or platform."
+        )
+      )
+    }
+    # Expect screenshot
+    app_expect_screenshot(self, private, ...)
   }
-  # Expect screenshot
-  app_expect_screenshot(self, private, ...)
-}
 
 
 handle_custom_selector <- function(self, private, screenshot_args) {
@@ -135,10 +164,10 @@ handle_custom_selector <- function(self, private, screenshot_args) {
     return(screenshot_args)
   }
   # If not an option, quit early
-  if (!(
-    selector == "viewport" ||
-    selector == "scrollable_area"
-  )) {
+  if (
+    !(selector == "viewport" ||
+      selector == "scrollable_area")
+  ) {
     return(screenshot_args)
   }
 
@@ -148,17 +177,20 @@ handle_custom_selector <- function(self, private, screenshot_args) {
   # > a numeric vector with 4 elements (for left, top, width, and height)
   # Related: set `html` height to viewport size https://github.com/rstudio/shinycoreci/blob/de7676a9eca61e4dd191c0eb2e6f5c65b9119c8a/inst/apps/303-bslib-html-template/template.html#L9
   screenshot_args$cliprect <-
-    switch(selector,
+    switch(
+      selector,
       "viewport" = {
         # message("Using viewport height and width!")
         # Get the window height and width
         window_size <- self$get_window_size()
-        scroll_start <- self$get_js("(function() {
+        scroll_start <- self$get_js(
+          "(function() {
           return {
             scrollX: window.scrollX,
             scrollY: window.scrollY
           }
-        })()")
+        })()"
+        )
         # > a numeric vector with 4 elements (for left, top, width, and height)
         c(
           scroll_start$scrollX,
@@ -169,13 +201,15 @@ handle_custom_selector <- function(self, private, screenshot_args) {
       },
       "scrollable_area" = {
         # message("Using scroll height and width!")
-        scroll_size <- self$get_js("(function() {
+        scroll_size <- self$get_js(
+          "(function() {
           const html = document.querySelector('html')
           return {
             height: html.scrollHeight,
             width: html.scrollWidth
           }
-        })()")
+        })()"
+        )
         c(0, 0, scroll_size$width, scroll_size$height)
       },
       # Safety
